@@ -99,3 +99,6 @@ Lang_HelpGuide = "Help Guide";
 Lang_ExportToIcal = "Export to iCal";
 
 Lang_HasNoMsgs = "$var['FolderName'] has no messages";
+
+Lang_CalImportTitle = "Import from iCal";
+Lang_CalImportLabel = "Import Calendar in iCal (ics) format:";
