@@ -134,7 +134,11 @@ function newlang($langname, $file)
     html_search("./lang/$langname/msg/");
     html_search("./lang/$langname/simple/");
     //html_search("./lang/$langname/simple/heading/");
-    //html_search("./lang/$langname/xhtml/");
+    
+
+    if(is_dir("./lang/$langname/xhtml/"))
+    html_search("./lang/$langname/xhtml/");
+    
     html_search("./lang/$langname/xp/");
     //html_search("./lang/$langname/xp/heading/");
 
