@@ -2,8 +2,8 @@
 // +----------------------------------------------------------------+
 // | Abook.php  													|
 // +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2005 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: Febuary 2005												|
 // +----------------------------------------------------------------+
@@ -110,6 +110,8 @@ class Abook
 		// Take away ' , < and > characters from the Email ; they are illegal characters
 		$user['Email'] = str_replace(array("'", '<', '>'), '', $user['Email']);
 		$user['DateModified'] = ($user['DateModified'])? $user['DateModified'] : AtmailGlobal::outlook_date();
+		$user['UserDOB'] = ($user['UserDB']) ? $user['UserDB'] : '';
+		
 		$data = array(
 			$user['UserEmail'],
 			$user['UserEmail2'],
@@ -259,6 +261,54 @@ class Abook
 
 	        }
 	    }
+	    
+	    // let's get the ldap results and show them in the addressbook
+	    // _IF_ the config file says so!
+	    if ($pref['addressbook_ldap_entries']) {
+			$db['abookview'] = 'ldap';
+			$db['Account'] = '*';
+			$db['FirstName'] = '*';
+			$db['LastName'] = '*';
+			$ldap_results = $this->_search_ldap($db);
+	
+			// get highest array value for appending ldap stuff onto
+			$array_max = array_keys($h);
+			$key_max = max($array_max);
+	
+			// let's add 1 onto it as always! 
+			$max_id = $key_max;
+			$i = $max_id+1;
+ 
+			foreach($ldap_results as $ldap_entry) {
+				$temp['UserEmail']     = $ldap_entry['Account'];           
+				$temp['UserFirstName'] = $ldap_entry['UserFirstName'];
+				$temp['UserLastName']  = $ldap_entry['UserLastName'];
+				$temp['UserGender']    = '';                         
+				$temp['UserHomePhone'] = '';
+				$temp['UserWorkPhone'] = $ldap_entry['UserWorkPhone'];
+				$temp['id']            = $i;
+				$temp['ldap']          = 1;
+				$h[$i]                 = $temp;
+				$i+=1;         
+			}
+
+			// determine sort function to use
+			$sortfunction = "sort" . $sort;
+	
+			// sort functions for array shenanigans (messy perhaps?!)
+			function sortUserEmail($a,$b) { return (strcmp ($a['UserEmail'],$b['UserEmail'])); }
+			function sortUserLastName($a,$b) { return (strcmp ($a['UserLastName'],$b['UserLastName'])); }
+			function sortUserWorkPhone($a,$b) { return (strcmp ($a['UserWorkPhone'],$b['UserWorkPhone'])); }
+			function sortUserHomePhone($a,$b) { return (strcmp ($a['UserHomePhone'],$b['UserHomePhone'])); }
+	
+			// sort the array out
+			uasort($h, $sortfunction);
+	
+			// reverse that array if we're descending (never used at present?)
+			if ($direction == 'desc') {
+				array_reverse($h, TRUE);
+			}
+	    }
 
 	    return $h;
 	}
@@ -459,6 +509,38 @@ class Abook
 
 	    }
 
+		// do we want to autocomplete using ldap server?
+	    if ($pref['autocomplete_ldap_entries']) {
+	    	
+			$db['abookview'] = 'ldap';
+			$db['Account']   = str_replace('%','',$db['Account']);
+			$db['Account']   = str_replace("'",'',$db['Account']);
+			$db['FirstName'] = str_replace('%','',$db['FirstName']);
+			$db['FirstName'] = str_replace("'",'',$db['FirstName']);
+			$db['LastName']  = str_replace('%','',$db['LastName']);
+			$db['LastName']  = str_replace("'",'',$db['LastName']);
+			
+			$ldap_results    = $this->_search_ldap($db);
+			
+			$max_id = $this->db->sqlarray("SELECT max(id)
+	                                          FROM $this->Abook
+	                                          WHERE Account = $this->Account_Escape $extend
+	                                          ORDER BY $this->Abook.$sort $limit");
+	
+			$i = $max_id[0]+1;
+	
+			foreach($ldap_results as $ldap_entry) {
+			   $temp['UserEmail']     = $ldap_entry['Account'];
+			   $temp['UserFirstName'] = $ldap_entry['UserFirstName'];
+			   $temp['UserLastName']  = $ldap_entry['UserLastName'];
+			   $temp['id']            = $i;     
+			   $results[$i]           = $temp;               
+			   $i+=1;
+			}
+			
+			$results['FullTotal'] += count($ldap_results);
+	    }
+
 	    return $results;
 	}
 
@@ -1117,7 +1199,16 @@ class Abook
 		if (!@ldap_bind($ldap, $pref['bind_dn'], $pref['ldap_password']))
 			return array();
 
-		$query = "(& ";
+		//$query = "(& ";
+		$query = "(| ";
+
+		// we're doing a wildcard search
+		if ( ($db['Account'] == '*') && ($db['FirstName'] == '*') && ($db['LastName'] == '*') ) {
+			$db['Account'] = '';
+			$db['FirstName'] = '';
+			$db['LastName'] = '';
+			$query .= "(mail=*) ";
+		}
 
 		if (!empty($db['Account']))
 	        $query .= "(mail={$db['Account']}*) ";
@@ -1150,6 +1241,7 @@ class Abook
 		        $h[$email]['Account'] = $entry['mail'][0];
 		        $h[$email]['UserLastName'] = $entry['sn'][0];
 		        $h[$email]['UserFirstName'] = $entry['givenname'][0];
+		        $h[$email]['UserWorkPhone'] = $entry['telephonenumber'][0];
 		    }
 
 		    return $h;
