@@ -434,34 +434,6 @@ class Auth {
 		else
 			$settings['Mode'] = 'file';
 
-		// Create a temporary hash containg our new user settings
-		/*
-		if (!$user)
-		{
-			// Read the settings from our CGI vars, if no hash is specified already (e.g via migration script)
-			$user = $atmail->getinfo($user);
-		}
-		*/
-
-		if (preg_match('/^([A-Z])/i', $this->Account, $m))
-			$first = $m[1];
-		else
-			$first = 'other';
-
-		if (preg_match('/^[A-Z]([A-Z])/i', $this->Account, $m))
-			$second = $m[1];
-		else
-			$second = 'other';
-
-		// Create the users maildir in the Windows or Unix format
-		if (strpos(PHP_OS, 'WINNT') !== false)
-		{
-			$letter = (preg_match('/^(\w)/', $pref['win_drive'], $m)) ? $m[1] : 'c';
-
-			$user['MailDir'] = "/cygdrive/$letter/atmail4/users/$first/$second/$this->Account";
-		}
-		else
-			$user['MailDir'] = "{$pref['user_dir']}/users/$first/$second/$this->Account";
 
 
 		if (!$user['UserQuota'])
@@ -552,58 +524,9 @@ class Auth {
 			$mail->newfolder($folder);
 		}
 
-		// Generate user's PGP keypair in SQL backend
-		/* disabled for now
-	    if ($this->pgpGenerateKeys)
-	    {
-			require_once('PGP.php');
-
-			$userWrkDir = "{$pref['user_dir']}/users/$this->Account";
-	    	PGP::rmtree($userWrkDir);
-
-	    	$pgp = new PGP ( array('wrkDir' => "$userWrkDir/pgp") );
-			$pgp->genKey("{$user['FirstName']} {$user['LastName']}", $this->Account, $this->pgpPassword);
-			if ($pgp->ErrorMsg)
-				return $pgp->ErrorMsg;
-
-	    	// read keyrings and trustdb and write them in database
-	    	$content = '';
-	    	$atmail->db->sqldo( "INSERT INTO {$atmail->db->UserPgp} (Account) VALUES (?) ", $this->Account );
-
-	    	foreach (array("trustdb","pubring","secring","public") as $name)
-	    	{
-	    		$content = file_get_contents("$userWrkDir/pgp/$name.gpg");
-
-	    		// write the keys to database
-	    		$this->db->sqldo( "UPDATE {$atmail->db->UserPgp} SET $name=? WHERE Account = ?", array($content, $this->Account));
-	    	}
-
-	    	PGP::rmtree($userWrkDir);
-	    }
-	    */
 
 
-		// Optionally send the Welcome message
-//		if ( $_REQUEST['SendWelcome'] || $_REQUEST['NewUser'] )
-//        {
-//            require_once('SendMsg.php');
-//
-//            // Build the message to send
-//            $sendmsg = new SendMsg(array(
-//            'Account'      => $this->Account,
-//            'EmailTo'      => $this->Account,
-//            'EmailFrom'    => $this->Account,
-//            'EmailSubject' => "Welcome to your new Account",
-//            'ContentType'  => "text/html",
-//            'EmailMessage' => $atmail->parse($pref['welcome_msg'], array('Account' => $this->Account, 'FirstName' => $user['FirstName'])),
-//            'EmailBox'  => "Inbox",
-//            'EmailUIDL' => time().getmypid()));
-//
-//            $top = $sendmsg->buildmsg();
-//
-//            // Send the message via SMTP or pipe
-//            $sendmsg->deliver($top);
-//        }
+
         
 	    return 1;
 	}
@@ -633,6 +556,14 @@ class Auth {
 	{
 		global $atmail, $domains, $pref;
 
+		// Trigger plugin event.
+		// Only continue execution if event is not handled
+		$args = array('newpass' => $newpass);
+		$atmail->pluginHandler->triggerEvent('onChangePass', $args);
+		if (isset($args['handled'])) {
+		    return 1;
+		}
+		
 		$query = 'SELECT Password
 				  FROM UserSession
 				  WHERE Account = ?';
