@@ -2,14 +2,8 @@
 // +----------------------------------------------------------------+
 // | GetMail.php													|
 // +----------------------------------------------------------------+
-// | Function:  Retrieve msgs from a variety of sources				|
-// | * POP3															|
-// | * IMAP															|
-// | * Local - MailDir Format										|
-// | * SQL - @Mail Format											|
-// +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2005 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: February 2005											|
 // +----------------------------------------------------------------+
@@ -93,21 +87,6 @@ class GetMail
 
 		$this->MailDir = $this->sql->getvalue("select MailDir from Users where Account=?",$this->Account);
 
-		// All mailbox functions are now maildir for local accounts
-		if ($domains[$this->Pop3host])
-		{
-			$this->Type = "file";
-			$this->Mode = "file";
-		}
-
-		// Take out the cygdrive path under Windows
-		if (preg_match('/Win/', PHP_OS))
-		{
-			preg_match('/^(\w)/', $pref['win_drive'], $m);
-			$letter = ucfirst($m[1]);
-			$this->MailDir = str_replace("/cygdrive/$letter", "$letter:", $this->MailDir);
-			$this->MailDir = str_replace('/', '\\', $this->MailDir);
-		}
 
 		$this->SessionID = session_id();
 
@@ -1012,7 +991,7 @@ class GetMail
 		}
 
 	    $newdate = strtotime($newdate);
-		$ctime = localtime(null, true);
+		$ctime = localtime(time(), true);
 
 	    // Get the hour and minute of current time
 	    $hour   = $ctime['tm_hour'];
@@ -1548,6 +1527,12 @@ password for the account. Server returned ( $error )";
 
 	function clean_header($db)
 	{
+	    foreach ($db as $k => $v) {
+            foreach (range(0, 31) as $chr) {
+                $db[$k] = str_replace(chr($chr), '', $v);
+            }
+        }
+        
 		if (!$db['EmailSubject'])
 	    	$db['EmailSubject'] = "No Subject";
 
@@ -1787,8 +1772,16 @@ password for the account. Server returned ( $error )";
 	// Fix a header and take away unnessasary characters
 	function quote_header($header)
 	{
-		$header = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', GetMail::decode_mime_head(\'$1\', \'$2\'))', $header);
-		$header = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', base64_decode(\'$2\'))', $header);
+	    if (preg_match('/\s*=\?([^\?]+)\?([QqBb])/', $header, $m)) {
+	        if (strtoupper($m[2]) == 'Q') {
+                $header = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', GetMail::decode_mime_head(\'$1\', \'$2\'))', $header);
+	        } else {
+    		    $header = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', 'GetMail::decode_language(\'$1\', base64_decode(\'$2\'))', $header);
+	        }
+	    } else {
+	        $header = GetMail::decode_language('', $header);
+	    }
+
         $header = preg_replace('/(.+?)<(.*?)>/', '$1&lt;$2&gt;', $header);
         $header = str_replace(array('<', '>'), '', $header);
 	    $header = trim($header);
@@ -2191,21 +2184,11 @@ password for the account. Server returned ( $error )";
 	{
 	    if ( !$db['EmailSubject'] ) $db['EmailSubject'] = "No Subject";
 
-		if (preg_match('/\s*=\?([^\?]+)\?[QqBb]/', $db['EmailSubject']))
-		{
-			$db['EmailSubject'] = preg_replace('/\s*=\?([^\?]+)\?[Qq]\?([^\?]+)?\?=/e', "\$this->decode_language('\\1', GetMail::decode_mime_head('\\1', '\\2'))", $db['EmailSubject']);
-			$db['EmailSubject'] = preg_replace('/\s*=\?([^\?]+)\?[Bb]\?([^\?]+)?\?=/e', "\$this->decode_language('\\1', base64_decode('\\2'))", $db['EmailSubject']);
-		}
-		else
-			$db['EmailSubject'] = $this->decode_language($db['Charset'], $db['EmailSubject']);
-
 	    // Escape the EmailBoundary. Just in case.
 	    $db['EmailBoundary'] = preg_replace('/([()*+.?\\\])/', '\\$1', $db['EmailBoundary']);
 
 		if (isset($db['EmailMsg']) && !empty($db['EmailMsg']))
 		{
-			//$db['EmailMsg'] = $this->decode_language($db['Charset'], $db['EmailMsg']);
-
 			$db['EmailMsg'] = preg_replace("/=([\da-fA-F]{2})/e", "chr(hexdec('\\1'))", $db['EmailMsg']);
 		    $db['EmailMsg'] = substr($db['EmailMsg'], 0, 1000);
 
@@ -2220,8 +2203,9 @@ password for the account. Server returned ( $error )";
 			$db['EmailMsg'] = $this->decode_language($db['Charset'], $db['EmailMsg']);
 		}
 
-	    foreach ( $db as $k=>$v)
+	    foreach ( $db as $k=>$v) {
 	        $db[$k] = $this->quote_header($v);
+	    }
 
 		if ( !$db['EmailUIDL'] )
 		{
@@ -2540,52 +2524,77 @@ password for the account. Server returned ( $error )";
 		require_once('Date.php');
 
 		// convert to ISO 8601 format
-		if(preg_match('/(\d+) ([a-z]+) (\d\d\d\d) (\d\d:\d\d:\d\d) ((\+|-)\d\d\d\d|[a-z]+)/i', $newdate, $m))	{
+		if(preg_match('/(\d+) ([a-z]+) (\d\d\d?\d?) (\d\d:\d\d:\d\d) ((\+|-)\d\d\d\d|[a-z]+)/i', $newdate, $m)) {
 
-		if (strlen($m[1]) == 1)
-			$m[1] = "0$m[1]";
+		    if (strlen($m[1]) == 1)
+    			$m[1] = "0$m[1]";
 
-		// Convert Timezone ID to GMT offset
-		if (!is_numeric($m[5])) {
-			$dt = new Date_TimeZone($m[5]);
-			$m[5] = $dt->getRawOffset();
-			if ($m[5] == 0) {
-				$m[5] = 'Z';
-			} else {
-				$m[5] = $m[5] / 36000;
-				settype($m[5], 'string');
-				$m[5] = preg_replace('/(-|\+)/', '${1}0', $m[5]);
-			}
-		}
+    		// If a 2 digit date is given then we need to make an assumption
+    		// about the actual year. If year >= 80 we can safely assume that
+    		// it's a 20th Century date e.g. 89 becomes 1989. Otherwise lets make it
+    		// a 21st Century date, e.g. 08 becomes 2008
+    		if (strlen($m[3]) == 2) {
+    		    $m[3] = ($m[3] >= 80)? "19$m[3]" : "20$m[3]";
+    		}
 
-		$newdate = "$m[3]{$this->months[$m[2]]}$m[1]T$m[4]$m[5]";
+    		// format month name with uppercase firt char e.g Sep
+    		$m[2] = ucfirst(strtolower($m[2]));
 
-		// Do timezone conversion
-		$date = new Date($newdate);
+    		// Convert Timezone ID to GMT offset
+    		if (!is_numeric($m[5])) {
 
-		$date->convertTZbyID($this->TimeZone);
+    		    // convert UT > UTC
+    		    if ($m[5] == 'UT') {
+    		        $m[5] = 'UTC';
+    		    }
 
-		$newdate = $date->getDate();
+    			$dt = new Date_TimeZone($m[5]);
+    			$m[5] = $dt->getRawOffset();
+    			if ($m[5] == 0) {
+    				$m[5] = 'Z';
+    			} else {
+    				$m[5] = $m[5] / 36000;
+    				settype($m[5], 'string');
+    				$m[5] = preg_replace('/(-|\+)/', '${1}0', $m[5]);
+    			}
+    		}
 
-        $newdate = date("D, j M Y G:i O", strtotime($newdate));
-		} elseif(preg_match('/(\d+) ([a-z]+) (\d\d\d\d) (\d\d:\d\d:\d\d) (\w+)/i', $newdate, $m))	{
+    		$newdate = "$m[3]{$this->months[$m[2]]}$m[1]T$m[4]$m[5]";
 
-		if (strlen($m[1]) == 1)
-			$m[1] = "0$m[1]";
+    		// Do timezone conversion
+    		$date = new Date($newdate);
+    		$date->convertTZbyID($this->TimeZone);
 
-		$newdate = "$m[3]{$this->months[$m[2]]}$m[1]";
+    		$newdate = $date->getDate();
+            $newdate = date("D, j M Y G:i O", strtotime($newdate));
 
-		// Convert date from timezone ID, rather then +0900 or -1100 format, format in GMT, MST, etc
-		$date = new Date($newdate);
-		$date->setTZByID($m[5]);
+		} elseif (preg_match('/(\d+) ([a-z]+) (\d\d\d\d) (\d\d:\d\d:\d\d) (\w+)/i', $newdate, $m)) {
 
-		$newdate = $date->getDate();
-        $newdate = date("D, j M Y G:i O", strtotime($newdate));
+    		if (strlen($m[1]) == 1)
+    			$m[1] = "0$m[1]";
 
-		} else	{
+    		// If a 2 digit date is given then we need to make an assumption
+            // about the actual year. If year >= 80 we can safely assume that
+            // it's a 20th Century date e.g. 89 becomes 1989. Otherwise lets make it
+            // a 21st Century date, e.g. 08 becomes 2008
+            if (strlen($m[3]) == 2) {
+                $m[3] = ($m[3] >= 80)? "19$m[3]" : "20$m[3]";
+            }
 
-		$newdate = date("D, j M Y G:i O", strtotime($newdate));
+            // format month name with uppercase firt char e.g Sep
+            $m[2] = ucfirst(strtolower($m[2]));
 
+    		$newdate = "$m[3]{$this->months[$m[2]]}$m[1]";
+
+    		// Convert date from timezone ID, rather than +0900 or -1100 format, format in GMT, MST, etc
+    		$date = new Date($newdate);
+    		$date->setTZByID($m[5]);
+
+    		$newdate = $date->getDate();
+            $newdate = date("D, j M Y G:i O", strtotime($newdate));
+
+		} else {
+            $newdate = date("D, j M Y G:i O", strtotime($newdate));
 		}
 
 		return $newdate;
