@@ -2,8 +2,8 @@
 // +----------------------------------------------------------------+
 // | SendMsg.php													|
 // +----------------------------------------------------------------+
-// | Source-code (C) CalaCode.com 1998-2005 . All rights reserved	|
-// | See http://calacode.com/license.ehtml for license agreement	|
+// | AtMail Open - Licensed under the Apache 2.0 Open-source License|
+// | http://opensource.org/licenses/apache2.0.php                   |
 // +----------------------------------------------------------------+
 // | Date: Febuary 2005												|
 // +----------------------------------------------------------------+
@@ -133,7 +133,7 @@ class SendMsg
 	    $this->Date = date("D, j M Y H:i:s O", time());
 
 	    // return an error if To: field contains only , or ;
-        if ((strlen($this->EmailTo) == 0 || (!(preg_match('/\@/', $this->EmailTo)) && (preg_match('/,/', $this->EmailTo))) && $this->EmailBox != "Draft"))
+        if (strlen($this->EmailTo) == 0 || (!preg_match('/\@/', $this->EmailTo) && (preg_match('/,/', $this->EmailTo))) && $this->EmailBox != "Draft")
         {
           	return $this->smtperror("Please specify an email in the To: field $this->EmailTo");
         }
@@ -322,10 +322,6 @@ EOF;
 		        $this->$type = preg_replace('/^\s*;\s*/', '', $this->$type);
 		        $this->$type = str_replace(array(';', ' Shared Group', ' Group'), array(',', '@SharedGroup', '@Group'), $this->$type);
 
-		        // replace single quotes around the personal part with double quotes
-		        // otherwise any commas will break the parsing
-		        $this->$type = preg_replace("/'([^\"@]+?)'\s/", '"$1" ', $this->$type);
-
 		        // Remove "smart quotes" (aka dumb quotes)
 		        $smartquotes = array('“', '”', '‘', '’', "\x98", "\x99", "\x8c", "\x9d", chr(147), chr(148), chr(146), 'R20;', 'R21', 'R16;', 'R17');
 
@@ -442,7 +438,7 @@ EOF;
         if ($this->ReplyFwd == 'reply' || $this->ReplyFwd == 'forward')
             $this->_cleanLinks();
 
-	    // If user is using the HTML editor, send a HTML message otherwise plain txt
+        // If user is using the HTML editor, send a HTML message otherwise plain txt
 	    if ( strpos($this->ContentType, 'html') !== false )
 	    {
 	        $this->mime->headers(array(
@@ -454,13 +450,29 @@ EOF;
 	          	'X-Atmail-Account' => $this->Account,
 			  	'Date' 		=> $this->Date));
 
-			// add the text/html part
-			$this->mime->setHTMLBody($this->EmailMessage);
-
-			// Now create the text/plain part also
-			require_once('class.html2text.inc');
+	        // Now create the text/plain part also
+            require_once('class.html2text.inc');
             $html2text = new html2text($this->EmailMessage);
-			$this->mime->setTXTBody($html2text->get_text());
+            $txt = $html2text->get_text();
+            $txt = preg_replace('/^\s*BODY\s*\{.+?\}/s', '', $txt);
+
+            $html = $this->EmailMessage;
+            
+            // Cleanup PGP block if one exists
+	        if (strpos($this->EmailMessage, '-----BEGIN PGP MESSAGE-----') !== false) {
+	            $html = PGP::cleanPgpBlock($this->EmailMessage, 'message');
+	            $txt  = PGP::cleanPgpBlock($txt, 'message');
+	        }
+
+	        // Cleanup PGP block if one exists
+            if (strpos($this->EmailMessage, '-----BEGIN PGP PUBLIC KEY BLOCK-----') !== false) {
+                $html = PGP::cleanPgpBlock($this->EmailMessage, 'pubkey');
+                $txt  = PGP::cleanPgpBlock($txt, 'pubkey');
+            }
+
+            // add the text/html part
+			$this->mime->setHTMLBody($html);
+			$this->mime->setTXTBody($txt);
 	    }
 	    else
 	    {
@@ -594,7 +606,7 @@ EOF;
 	    }
 
 	    $this->body = $this->mime->get(array('text_encoding'=>'quoted-printable', 'html_encoding'=>'quoted-printable'));
-		$this->headers = trim($this->mime->txtHeaders());
+	    $this->headers = trim($this->mime->txtHeaders());
 	}
 
 
@@ -665,10 +677,6 @@ EOF;
 		if (!empty($this->EmailBCC))
 			$rcpt .= ",$this->EmailBCC";
 
-		// replace single quotes around the personal part with double quotes
-        // otherwise any commas will break the parsing
-        $rcpt = preg_replace("/'([^\"@]+?)'\s/", '"$1" ', $rcpt);
-
         // Remove personal part - it is not needed for send RCPT cmd
         // and just causes problems for the address parser if it contains
         // certain utf-8 chars (e.g. Japanese)
@@ -723,7 +731,7 @@ EOF;
 
 		require_once('Net/SMTP.php');
 
-	    $smtp = new Net_SMTP($pref['smtphost']);
+	    $smtp = new Net_SMTP($pref['smtphost'], null, $_SERVER['HTTP_HOST']);
 
 		//$smtp->setDebug(true);
 
@@ -1154,6 +1162,7 @@ EOF;
 
         return $string;
     }
+
 }
 
 ?>
