@@ -5,9 +5,8 @@
  * IMAP Client class. Can be used instead of PHP's
  * imap functions to communicate with an IMAP server
  *
- * @author Brad Kowalczyk <brad@ibiscode.com>
+ * @author Brad Kowalczyk <brad@staff.atmail.com>
  * @version 1.0
- * @copyright Calacode.com 2006
  * @package IMAP_Client
  */
 
@@ -122,10 +121,16 @@ class IMAP_Client
 				$this->capabilities = $resp;
 		}
 
+		//$this->startTLS();
 		return true;
 	}
 
-
+	
+	function startTLS()
+	{
+		$this->sendCMD('STARTTLS');		
+	}
+	
 	function disconnect()
 	{
 		if (is_a($this->socket, 'Net_Socket'))
@@ -281,6 +286,8 @@ class IMAP_Client
 	 */
 	function getMailboxSummary($start = null, $end = null, $mailbox = null, $lines = 0)
 	{
+		global $pref;
+
 		if (!$this->loggedIn)
 		{
 			$this->lastError = IC_NOT_LOGGED_IN;
@@ -304,17 +311,97 @@ class IMAP_Client
 		if ($this->total < 1)
 			return $summary;
 
-		if($lines > 0)
-		$resp = $this->sendCmd("FETCH $start:$end (UID FLAGS RFC822.SIZE rfc822.header BODY.PEEK[1]<0.250>)");
-		else
-		$resp = $this->sendCmd("FETCH $start:$end (UID FLAGS BODY.PEEK[HEADER] RFC822.SIZE)");
+		// check whether we're configured to use server side sorting
+		// and whether this server even has the sort extension available!
+		// NB: we ignore the 'id' (ARRIVAL) sort as simply using the
+		// msg sequence ids is faster as we can skip issuing the SORT
+		// command and processing its response.
+		if ( $var['sort'] !== 'id' && ($pref['imap_sort_extension']) && ($this->hasCapability('SORT')) ) {
 
-		$msgs = preg_split('/\* \d+ FETCH/', $resp);
+			global $var;
 
-		foreach ($msgs as $info)
-		{
-			if (!$info)
+			// get encoding
+			$encoding = ($pref['imap_sort_charset']) ? $pref['imap_sort_charset'] : 'us-ascii';
+
+			// use server side sorting
+			// sort that bad boy out depending on config
+			switch ($var['sort']) {
+				case "id":
+					$resp = $this->sendCmd("SORT (ARRIVAL) $encoding ALL");
+					break;
+				case "EmailSubject":
+					$resp = $this->sendCmd("SORT (SUBJECT) $encoding ALL");
+					break;
+				case "EmailFrom":
+					$resp = $this->sendCmd("SORT (FROM) $encoding ALL");
+					break;
+				case "EmailDate":
+					$resp = $this->sendCmd("SORT (DATE) $encoding ALL");
+					break;
+				default:
+					$resp = $this->sendCmd("SORT (ARRIVAL) $encoding ALL");
+					break;
+			}
+			// bugger
+			if (preg_match('/\d+ (NO|BAD) (.+)/', $resp, $m)) {
+				$this->lastError = $m[2];
+				return $summary;
+			}
+			// sorted!
+			$server_sort_array = array();
+			if (preg_match("/^\* SORT (.+)$/", $resp, $regs)) {
+				$server_sort_array = preg_split("/ /", trim($regs[1]));
+			}
+			// fekker
+			if ($var['sort'] == 'EmailSubject' || $var['sort'] == 'EmailFrom') {
+				$server_sort_array = array_reverse($server_sort_array);
+			}
+
+			$length = ($end - $start) + 1;
+			$server_sort_array = array_slice($server_sort_array, $start - 1, $length);
+			$msg_uids = join(',', $server_sort_array);
+
+			$var['sort'] = "id";
+
+			if($lines > 0)
+				$resp = $this->sendCmd("FETCH $msg_uids (UID FLAGS RFC822.SIZE rfc822.header BODY.PEEK[1]<0.250>)");
+			else
+				$resp = $this->sendCmd("FETCH $msg_uids (UID FLAGS BODY.PEEK[HEADER] RFC822.SIZE)");
+
+			$msgs = preg_split('/\* \d+ FETCH/', $resp);
+
+		} else {
+			// do not use server side sorting
+			if($lines > 0) {
+				$resp = $this->sendCmd("FETCH $start:$end (UID FLAGS RFC822.SIZE rfc822.header BODY.PEEK[1]<0.250>)");
+			} else {
+				$resp = $this->sendCmd("FETCH $start:$end (UID FLAGS BODY.PEEK[HEADER] RFC822.SIZE)");
+			}
+
+			$msgs = preg_split('/\* \d+ FETCH/', $resp);
+		}
+
+		$summary = $this->_processMessageSummaries($msgs);
+
+		return $summary;
+	}
+
+
+	/**
+	 * Get summaries for an array of messages
+	 *
+	 * @param array $msgs The array of messages to process
+	 * @return array
+	 */
+	function _processMessageSummaries($msgs)
+	{
+		$summary = array();
+
+		foreach ($msgs as $info) {
+
+			if (!$info) {
 				continue;
+			}
 
 			// Extract the UID
 			if (preg_match('/UID\s+(\d+)/i', $info, $m)) {
@@ -333,57 +420,28 @@ class IMAP_Client
 			// Extract the size from the response
 			preg_match('/RFC822\.SIZE\s*(\d+)/i', $info, $m);
 			$size = $m[1];
-			//$info = preg_replace('/RFC822\.SIZE\s*(\d+)/i', '', $info);
 
 			// Extract the Flags from the response
 			preg_match('/FLAGS\s*\(\\\(.*?)\)/', $info, $m);
 			$flags = $m[1];
 
-			if(preg_match('/Deleted/i', $flags))
-			$flags = 'd';
-			elseif(preg_match('/Flagged/i', $flags))
-			$flags = 'm';
-			elseif(preg_match('/Answered/i', $flags))
-			$flags = 'r';
-			elseif(preg_match('/Seen/i', $flags))
-			$flags = 'o';
-			else
-			$flags = '';
+			if(preg_match('/Deleted/i', $flags)) {
+				$flags = 'd';
+			} elseif(preg_match('/Flagged/i', $flags)) {
+				$flags = 'm';
+			} elseif(preg_match('/Answered/i', $flags)) {
+				$flags = 'r';
+			} elseif(preg_match('/Seen/i', $flags)) {
+				$flags = 'o';
+			} else {
+				$flags = '';
+			}
 
 			// Strip the IMAP server response string
 			$info = preg_replace('/^\s*\(UID.+?$/ims', '', $info);
 			$info = preg_replace('/^\s+/ms', '', $info);
 
 			$summary[] = array('header' => $info, 'EmailSize' => $size, 'UIDL' => $flags, 'UID' => $uid, 'EmailMsg' => $EmailMsg);
-
-			//echo $info . "<HR>";
-
-			/*
-			// Extract the Date from the response
-			preg_match('/^Date:(.+)/im', $info, $m);
-			$date = $m[1];
-
-			// Extract the Subject from the response
-			//preg_match('/Subject:(.+?)\s*(Date:|From:|To:|\))/i', $line, $m);
-			preg_match('/^Subject:(.+)/im', $info, $m);
-			$subject = $this->mimeWordDecode($m[1]);
-
-			// Extract the Sender from the response
-			preg_match('/^From:(.+)/im', $info, $m);
-			$from = $this->mimeWordDecode($m[1]);
-
-			// Extract the Recipient from the response
-			preg_match('/^To:(.+)/im', $info, $m);
-			$to = $this->mimeWordDecode($m[1]);
-
-			$summary[] = array('date'    => $date,
-							   'subject' => $subject,
-							   'from'    => $from,
-							   'to'      => $to,
-							   'flags'   => $flags,
-							   'size'    => $size);
-
-			*/
 		}
 
 		return $summary;
@@ -530,32 +588,38 @@ class IMAP_Client
 		// Check the namespace command returns success
 		if (preg_match('/^\*/', $resp, $m))	{
 
-		$resp = preg_replace("/\x0d?\x0a$/", '', $resp);
+            $resp = preg_replace("/\x0d?\x0a$/", '', $resp);
 
-		// A standard response from the namespace command, e.g Courier-IMAP
-		preg_match('/(NIL|\((?:\([^\)]+\)\s*)+\))\s(NIL|\((?:\([^\)]+\)\s*)+\))\s(NIL|\((?:\([^\)]+\)\s*)+\))/', $resp, $m);
+            // A standard response from the namespace command, e.g Courier-IMAP
+            preg_match('/(NIL|\((?:\([^\)]+\)\s*)+\))\s(NIL|\((?:\([^\)]+\)\s*)+\))\s(NIL|\((?:\([^\)]+\)\s*)+\))/', $resp, $m);
 
-		if(is_array($m))	{
-			$this->PersonalPrefix = $m[1];
-			$this->PersonalPrefix = preg_match("/\"(.*?)\" \"(.*?)\"/", $this->PersonalPrefix, $imapfol);
+            if(is_array($m))	{
+                $this->PersonalPrefix = $m[1];
+                $this->PersonalPrefix = preg_match("/\"(.*?)\" \"(.*?)\"/", $this->PersonalPrefix, $imapfol);
 
-				if(is_array($imapfol))	{
-				$this->Prefix = $imapfol[1];
-				$this->Deliminator = $imapfol[2];
-				}
+                    if(is_array($imapfol))	{
+                    $this->Prefix = $imapfol[1];
+                    $this->Deliminator = $imapfol[2];
+                    }
 
-		}
+            }
 
-		} else if (preg_match('/NO The command "NAMESPACE" is unsupported in this state/', $resp))	{
+		} elseif (preg_match('/NO The command "NAMESPACE" is unsupported in this state/', $resp)) {
 			// Workaround for an IMAP server which does not support the namespace command, but Inbox/ is the prefix
 			$this->Prefix = 'Inbox/';
 			$this->Deliminator = '';
-		} else	{
+		} else {
 			// There is no prefix nor namespace
 			$this->Prefix = '';
 			$this->Deliminator = '';
 		}
 
+        // Double check
+        if ($this->Prefix == '' && !$this->select('Trash') && $this->select('INBOX.Trash')) {
+            $this->Prefix = 'INBOX.';
+            $this->Deliminator = '.';
+        }
+
 }
 	/**
 	 * Get an email from the server complete
@@ -726,16 +790,36 @@ class IMAP_Client
 	 * @param int $uid The message UID
 	 * @return string on success, bool false on error
 	 */
-	function getFlags($uid)
+	function getFlags($uid, $type='')
 	{
 	    // Fetch the message flags
 		$resp = $this->sendCmd("UID FETCH $uid (FLAGS)");
 		if (!$resp)
 			return false;
 
+		if(!$type)
 		return $resp;
-	}
+		else {
 
+			// Extract the Flags from the response
+			preg_match('/FLAGS\s*\(\\\(.*?)\)/', $resp, $m);
+			$flags = $m[1];
+
+			if(preg_match('/Deleted/i', $flags))
+			$flags = 'd';
+			elseif(preg_match('/Flagged/i', $flags))
+			$flags = 'm';
+			elseif(preg_match('/Answered/i', $flags))
+			$flags = 'r';
+			elseif(preg_match('/Seen/i', $flags))
+			$flags = 'o';
+			else
+			$flags = '';
+
+			return $flags;
+
+		}
+	}
 
 	/**
 	 * Mark messages to be deleted
@@ -953,7 +1037,7 @@ class IMAP_Client
 			$this->sendCmd("SUBSCRIBE \"$newName\"");
 
 			// get list of subfolders
-			$subs = $this->listMailboxes('', "$curName.*", false);
+			$subs = $this->listMailboxes('', "$curName.*", true);
 
 			foreach ($subs as $sub) {
 				$sub = $this->encodeUTF7($sub);
