@@ -10,7 +10,7 @@
 // +----------------------------------------------------------------+
 
 require_once('header.php');
-
+require_once('GetMail.php');
 require_once('Session.php');
 require_once('Global.php');
 
@@ -28,7 +28,7 @@ $redirect = $_REQUEST['redirect'];
 // No auth necessary to display login page
 if ($filename == 'html/login-light.html') {
     echo $atmail->parse('html/login-light.html');
-    exit;
+    $atmail->end();
 }
 
 $atmail->status = $auth->getuser();
@@ -140,6 +140,9 @@ $type["html/$atmail->Language/help/imgs"] = 1;
 $type["html/$atmail->Language/help/import.html"] = 1;
 $type["html/$atmail->Language/help/index.html"] = 1;
 $type["html/$atmail->Language/help/installation_help"] = 1;
+$type["html/$atmail->Language/help/iphonehelp.html"] = 1;
+$type["html/$atmail->Language/help/iphonehelphow.html"] = 1;
+$type["html/$atmail->Language/help/iphonehelptroub.html"] = 1;
 $type["html/$atmail->Language/help/ldap_faq.html"] = 1;
 $type["html/$atmail->Language/help/ldap.html"] = 1;
 $type["html/$atmail->Language/help/mailerror.html"] = 1;
@@ -217,6 +220,7 @@ $var['mailstyle'] = $atmail->parse("html/$atmail->Language/$atmail->LoginType/at
 }
 */
 
+include('snippets/quota_bar.php');
 
 $result =  $atmail->parse( $filename, $var );
 
@@ -236,4 +240,4 @@ print $result;
 
 $atmail->end();
 
-?>
\ No newline at end of file
+?>
