@@ -58,6 +58,8 @@ else
 	$var['sort'] = 'id';
 
 $var['order']     = ($_REQUEST['order'])? $_REQUEST['order'] : '';
+$var['order'] = Filter::stringMatch($var['order'], array('desc', 'asc'));
+
 $var['flag']      = $_REQUEST['Flag'];
 
 $var['XML']		  = $_REQUEST['XML'];
@@ -328,12 +330,6 @@ EOF;
 		if (strtoupper($folder) == "INBOX")
 			continue;
 
-		// Take out the folder-path, SQL mailboxes use the raw directory name, not folder/sublevel
-		if ($atmail->Mode == 'sql' && $atmail->MailType != 'imap')
-		{
-			$folderlink = preg_replace('/.*\//', '', $folder);
-		}
-		else
             $folderlink = $folder;
 
 		// Determine if we are the selected folder
@@ -427,6 +423,11 @@ if ($var['prevtotal'] && $var['total'] > $var['prevtotal'] )
                      <script language='Javascript'>this.window.focus();</script>";
 }
 
+// Filter out bad values
+if (isset($_REQUEST['start']) && !is_numeric($_REQUEST['start'])) {
+    $_REQUEST['start'] = '';
+}
+
 if ($_REQUEST['start'])
 	$var['msg_pos'] = $_REQUEST['start'];
 elseif ($var['total'] > $atmail->MsgNum)
@@ -461,7 +462,7 @@ if ( $var['msg_pos'] + $atmail->MsgNum <= $var['total'] )
 	$var['total'] = $var['msg_pos'] + $atmail->MsgNum;
 
 // Get the list of users who are spam blocked
-$spam_hash = $atmail->spam_hash();
+//$spam_hash = $atmail->spam_hash();
 $var['count'] = 0;
 
 // Finally print the table containing the messages
@@ -716,7 +717,7 @@ foreach ($emails as $email)
 
 	$email = array_merge($email, $mail->message_headers($email['header'], $id));
 	$email = $mail->cleanbody($email);
-	
+
     // Create cache id for email. Added check for existing cache ID to help avoid any
 	// clash where two emails have the same EmailUIDL e.g same address appears multiple
 	// times in To, CC, or BCC headers
@@ -802,63 +803,9 @@ foreach ($emails as $email)
 	{
 	    echo $atmail->parse("html/$atmail->Language/$atmail->LoginType/emailentry{$var['style']}{$var['suffix']}.html",
 	      array_merge($email, array('msgnum' => $i, 'count' => $var['count'], 'encfolder' => urlencode($email['folder']))));
-	    
-	    // START MAILOS
-	    if ($pref['mailos']) {
-	    	$threads = $mailos->mailos_list_threads($email['EmailUIDL']);
 
-	    	$mail->msgid_move2cur('Sent');
-	    	
-	    	foreach ($threads as $thread) {
-	    		
-				$cnt++;
-				$db = $mail->gethead( $thread, "Sent", 9, $atmail->Advanced );
-	    		$db = $mail->clean_header( $db, array('TimeZone' => $atmail->TimeZone, 'LoginType' => $atmail->LoginType));
-
-				// If we are using the Ajax interface convert &'s to <>
-				if ($atmail->Ajax || $atmail->XUL)
-				{
-					list($db['EmailSubject'], $db['EmailFrom'], $db['EmailTo'], $db['ReplyTo']) = str_replace( array('&gt;', '&lt;'), array('>', '<'), array($db['EmailSubject'], $db['EmailFrom'], $db['EmailTo'], $db['ReplyTo']));
-				}
-
-			    // If using the sent folder, we want to display the To field
-			    if ( $var['folder'] == 'Sent' )
-			    	$db['EmailFrom'] = $db['EmailTo'];
-			
-			    // Choose which colour the next row is
-			    $var['class'] = ( $var['class'] == 'item' ) ? 'item2' : 'item';
-			    $db['class']  = $var['class'];
-		        $db['msgclass'] = 'itemi';
-		        $db['folder'] = 'Sent';
-
-				if ($atmail->XUL) {
-					// Extract the src into a RDF tag
-					// Extract the src into a RDF tag
-					$db['ReadTag'] = '';
-					
-					// Extra the attachment
-					if (strpos($db['EmailAttach'], 'attachment.gif')  !== false) {
-						$db['EmailAttach'] = 'imgs/attachment.gif';
-					} else  {
-						$db['EmailAttach'] = '';
-					}
-				
-					$db['rowstyle'] = 'itemthread';
-
-					$var['xulstyle'] .= "<RDF:li resource=\"http://www.atmail.com/rdf/MESSAGES/$cnt$i\" />\n";
-					print $atmail->parse(
-				     "html/$atmail->Language/$atmail->LoginType/emailentry{$var['style']}.html",
-				      array_merge($db, array('msgnum' => "$cnt$i", 'count' => $var['count']))
-				    );
-				} else  {
-				    print $atmail->parse(
-				     "html/$atmail->Language/$atmail->LoginType/emailentry_mailos.html",
-				      array_merge($db, array('msgnum' => $i, 'count' => $var['count']))
-				    );
-				}
-        	}
-			// MAILOS END
-	    }
+        $args = array();
+        $atmail->pluginHandler->triggerEvent('onEchoedEmailEntry', $args);
 	}
 	else
 	{
@@ -870,6 +817,9 @@ foreach ($emails as $email)
 
 		$d[$id] = $atmail->parse("html/$atmail->Language/$atmail->LoginType/emailentry{$var['style']}{$var['suffix']}.html",
 			array_merge($email, array('msgnum' => $i, 'count' => $var['count'], 'encfolder' => urlencode($email['folder']))));
+
+		$args = array();
+        $atmail->pluginHandler->triggerEvent('onBufferedEmailEntry', $args);
 	}
 
     $var['count']++;
